var express = require('express');
var url = require('url');
var app = express();
var process = require('process');
var request = require('request');
var exphbs  = require('express-handlebars');
var bodyParser = require("body-parser");
var config = require(__dirname + '/config.json');

var logrotate = require('logrotator');
var rotator = logrotate.rotator;
rotator.register('/var/log/artix/artix-sale-renderer/artix-sale-renderer.log', {
  schedule: '5m', 
  size: '10m', 
  compress: true, 
  count: 3, 
  format: function(index) {
    var d = new Date();
    return d.getDate()+"-"+d.getMonth()+"-"+d.getFullYear();
  }
});


// Настройка хелперов handlebars. Хелперы позволяют выполнить какие-то действия с данными
// на уровне шаблона.

var hbs = exphbs.create({
  helpers: {
    'getTime': function(data) {
      var d = new Date(data);
        var timeOptions = {
            hour: 'numeric',
            minute: 'numeric'
        };
        return d.toLocaleTimeString("ru", timeOptions);
    },
    'getDate' : function(date) {
      var d = new Date(date);
      return d.toLocaleDateString();
    },
    'calcDiscountSum' : function(data) {
      var total =  0.00;
      for(var i=0;i<data.inventPositions.length;i++)
      {
        total += parseFloat(data.inventPositions[i].sume.toFixed(2));
      }
      return (total.toFixed(2) - parseFloat(data.docSum)).toFixed(2);
    },
    'getDiscountMode' : function(data) {
      if (data.discType == "percent") {
        return "Сумма скидки " + data.discSize + "%";
      } else if (data.discType == "summ") {
        return "Сумма скидки";
      } else if (data.discType == "price") {
        return "Специальная цена"
      } else if (data.discType == "bonus") {
        return "Скидка по бонусам " + data.discSize;
      } else if (data.discType == "index") {
        return "Индексная скидка"
      } else {
        return "Скидка";
      }
    },
    'isNotEmpty' : function(data) {
      if (data.length > 0) {
        return true;
      } else {
        return false;
      }
    }
  }
});

app.engine('handlebars', hbs.engine);
app.set('view engine', 'handlebars');
app.use(bodyParser.json());

var data = {
  CS_SERVER_HOST: process.env.CS_SERVER_HOST || config.CS_SERVER_HOST,
  CS_SERVER_PORT: process.env.CS_SERVER_PORT || config.CS_SERVER_PORT,
  SR_PORT: process.env.SR_PORT || config.SR_PORT
};

// routing
// выдача чека по идентификатору
app.get('/v1/getReceiptAsImage', function(req, res) {
  var url_parts = url.parse(req.url, true);
  var query = url_parts.query;
  if (query.id === undefined) {
    res.send("Не указан идентификатор чека (поле id)");
  }  
  var csUrl = 'http://' + data.CS_SERVER_HOST +  ':' + data.CS_SERVER_PORT +  '/CSrest/rest/sales/document/' + query.id;
  console.log(csUrl);
    request(csUrl, function (error, response, body) {
      if (!error && response.statusCode == 200) {
        var receipt = JSON.parse(body);
        var toTemplate = {'receipt' : receipt[0]};
        res.render(__dirname + '/views/layouts/main.handlebars', toTemplate);
      } else {
        res.send("Сервис недоступен");
      }
});
});

app.post('/v1/renderReceiptAsImage', function(req, res) {
  console.log("Построение документа для: ");
  console.log(req.body);
  if (!req.body) return res.sendStatus(400);
  res.render(__dirname + '/views/layouts/main.handlebars', {'receipt' : req.body});
});

app.use("/v1/css", express.static(__dirname + "/css"));
app.use(express.static('css'));
app.listen(data.SR_PORT);
module.exports = app;